@@ -22,3 +22,5 @@ from ._read_excel import read_excel
 from ._drop_bad_columns import drop_bad_columns
 from ._count_rows_with_missing import count_rows_with_missing, count_rows_without_missing
 from ._apply_function import apply_function
+from ._assert_has_columns import assert_has_columns
+from .NearestFinder import NearestFinder
